Learn R Programming

Brundle (version 1.0.9)

jg.controlPeaks: Example ChIP-seq Control Peakset

Description

This data set is a matrix of example peaks for normalisation of ChIP-seq data

Usage

jg.controlPeaks

Arguments

Format

a matrix of locations and counts per experimental sample