Learn R Programming

Brundle (version 1.0.9)

jg.controlPeakset: Example ChIP-seq Control Peakset

Description

This data set is a matrix of example control peaks for normalisation of ChIP-seq data

Usage

jg.controlPeakset

Arguments

Format

a matrix of locations and counts per control sample