Learn R Programming

Brundle (version 1.0.9)

jg.runDeSeq: jg.runDeSeq

Description

Runs DESeq2 on our peakset after we have obtained the normalised size factors.

Usage

jg.runDeSeq(jg.PeaksetDeSeq, jg.conditions, jg.SizeFactors = NULL)

Arguments

jg.PeaksetDeSeq

is the experimental peakset formatted for DESeq2

jg.conditions

is the list of conditions to be compared

jg.SizeFactors

is the size factors generated from the control samples

Examples

Run this code
# NOT RUN {
data(jg.controlPeaksetDeSeq,package="Brundle")
data(jg.conditions,package="Brundle")
jg.controlSizeFactors = estimateSizeFactorsForMatrix(jg.controlPeaksetDeSeq)
jg.runDeSeq(jg.controlPeaksetDeSeq,jg.conditions, jg.SizeFactors = NULL)
# }

Run the code above in your browser using DataLab