jg.countAlignedMReads: jg.countAlignedMReads
Description
This function counts the number of aligned reads in millions from a list of
bam files. It returns these in as a list of numbers in the same order.
Usage
jg.countAlignedMReads(jg.bamFiles)
Arguments
jg.bamFiles
is a list of bam files to count.